nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Cbcmr

Struct Cbcmr 

#[repr(transparent)]
pub struct Cbcmr(pub u32);
CCM Bus Clock Multiplexer Register

Tuple Fields

0: u32

Implementations

Source

impl Cbcmr

pub const fn lpspi_clk_sel(&self) -> LpspiClkSel

Selector for lpspi clock multiplexer

pub const fn set_lpspi_clk_sel(&mut self, val: LpspiClkSel)

Selector for lpspi clock multiplexer

pub const fn periph_clk2_sel(&self) -> PeriphClk2Sel

Selector for peripheral clk2 clock multiplexer

pub const fn set_periph_clk2_sel(&mut self, val: PeriphClk2Sel)

Selector for peripheral clk2 clock multiplexer

pub const fn trace_clk_sel(&self) -> TraceClkSel

Selector for Trace clock multiplexer

pub const fn set_trace_clk_sel(&mut self, val: TraceClkSel)

Selector for Trace clock multiplexer

pub const fn pre_periph_clk_sel(&self) -> PrePeriphClkSel

Selector for pre_periph clock multiplexer

pub const fn set_pre_periph_clk_sel(&mut self, val: PrePeriphClkSel)

Selector for pre_periph clock multiplexer

pub const fn lpspi_podf(&self) -> LpspiPodf

Divider for LPSPI. Divider should be updated when output clock is gated.

pub const fn set_lpspi_podf(&mut self, val: LpspiPodf)

Divider for LPSPI. Divider should be updated when output clock is gated.