Struct Ccgr1
Source #[repr(transparent)]
pub struct Ccgr1(pub u32);
CCM Clock Gating Register 1
lpspi1 clocks (lpspi1_clk_enable)
lpspi1 clocks (lpspi1_clk_enable)
lpspi2 clocks (lpspi2_clk_enable)
lpspi2 clocks (lpspi2_clk_enable)
pit clocks (pit_clk_enable)
pit clocks (pit_clk_enable)
adc1 clock (adc1_clk_enable)
adc1 clock (adc1_clk_enable)
gpt1 bus clock (gpt_clk_enable)
gpt1 bus clock (gpt_clk_enable)
gpt1 serial clock (gpt_serial_clk_enable)
gpt1 serial clock (gpt_serial_clk_enable)
lpuart4 clock (lpuart4_clk_enable)
lpuart4 clock (lpuart4_clk_enable)
gpio1 clock (gpio1_clk_enable)
gpio1 clock (gpio1_clk_enable)
csu clock (csu_clk_enable)
csu clock (csu_clk_enable)
gpio5 clock (gpio5_clk_enable)
gpio5 clock (gpio5_clk_enable)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.