nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Ccgr3

Struct Ccgr3 

#[repr(transparent)]
pub struct Ccgr3(pub u32);
CCM Clock Gating Register 3

Tuple Fields

0: u32

Implementations

Source

impl Ccgr3

pub const fn cg0(&self) -> u8

Reserved

pub const fn set_cg0(&mut self, val: u8)

Reserved

pub const fn cg1(&self) -> u8

Reserved

pub const fn set_cg1(&mut self, val: u8)

Reserved

pub const fn cg2(&self) -> u8

Reserved

pub const fn set_cg2(&mut self, val: u8)

Reserved

pub const fn cg3(&self) -> u8

Reserved

pub const fn set_cg3(&mut self, val: u8)

Reserved

pub const fn cg4(&self) -> u8

aoi1 clock (aoi1_clk_enable)

pub const fn set_cg4(&mut self, val: u8)

aoi1 clock (aoi1_clk_enable)

pub const fn cg5(&self) -> u8

Reserved

pub const fn set_cg5(&mut self, val: u8)

Reserved

pub const fn cg6(&self) -> u8

Reserved

pub const fn set_cg6(&mut self, val: u8)

Reserved

pub const fn cg7(&self) -> u8

ewm clocks (ewm_clk_enable)

pub const fn set_cg7(&mut self, val: u8)

ewm clocks (ewm_clk_enable)

pub const fn cg8(&self) -> u8

wdog1 clock (wdog1_clk_enable)

pub const fn set_cg8(&mut self, val: u8)

wdog1 clock (wdog1_clk_enable)

pub const fn cg9(&self) -> u8

flexram clock (flexram_clk_enable)

pub const fn set_cg9(&mut self, val: u8)

flexram clock (flexram_clk_enable)

pub const fn cg10(&self) -> u8

Reserved

pub const fn set_cg10(&mut self, val: u8)

Reserved

pub const fn cg11(&self) -> u8

Reserved

pub const fn set_cg11(&mut self, val: u8)

Reserved

pub const fn cg12(&self) -> u8

Reserved

pub const fn set_cg12(&mut self, val: u8)

Reserved

pub const fn cg13(&self) -> u8

Reserved

pub const fn set_cg13(&mut self, val: u8)

Reserved

pub const fn cg14(&self) -> u8

The OCRAM clock cannot be turned off when the CM cache is running on this device.

pub const fn set_cg14(&mut self, val: u8)

The OCRAM clock cannot be turned off when the CM cache is running on this device.

pub const fn cg15(&self) -> u8

iomuxc_snvs_gpr clock (iomuxc_snvs_gpr_clk_enable)

pub const fn set_cg15(&mut self, val: u8)

iomuxc_snvs_gpr clock (iomuxc_snvs_gpr_clk_enable)