nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Ccosr

Struct Ccosr 

#[repr(transparent)]
pub struct Ccosr(pub u32);
CCM Clock Output Source Register

Tuple Fields

0: u32

Implementations

Source

impl Ccosr

pub const fn clko1_sel(&self) -> Clko1Sel

Selection of the clock to be generated on CCM_CLKO1

pub const fn set_clko1_sel(&mut self, val: Clko1Sel)

Selection of the clock to be generated on CCM_CLKO1

pub const fn clko1_div(&self) -> Clko1Div

Setting the divider of CCM_CLKO1

pub const fn set_clko1_div(&mut self, val: Clko1Div)

Setting the divider of CCM_CLKO1

pub const fn clko1_en(&self) -> Clko1En

Enable of CCM_CLKO1 clock

pub const fn set_clko1_en(&mut self, val: Clko1En)

Enable of CCM_CLKO1 clock

pub const fn clk_out_sel(&self) -> ClkOutSel

CCM_CLKO1 output to reflect CCM_CLKO1 or CCM_CLKO2 clocks

pub const fn set_clk_out_sel(&mut self, val: ClkOutSel)

CCM_CLKO1 output to reflect CCM_CLKO1 or CCM_CLKO2 clocks

pub const fn clko2_sel(&self) -> Clko2Sel

Selection of the clock to be generated on CCM_CLKO2

pub const fn set_clko2_sel(&mut self, val: Clko2Sel)

Selection of the clock to be generated on CCM_CLKO2

pub const fn clko2_div(&self) -> Clko2Div

Setting the divider of CCM_CLKO2

pub const fn set_clko2_div(&mut self, val: Clko2Div)

Setting the divider of CCM_CLKO2

pub const fn clko2_en(&self) -> Clko2En

Enable of CCM_CLKO2 clock

pub const fn set_clko2_en(&mut self, val: Clko2En)

Enable of CCM_CLKO2 clock