#[repr(transparent)]pub struct Ccsr(pub u32);Expand description
CCM Clock Switcher Register
Tuple Fields
0: u32Implementations
Sourceimpl Ccsr
impl Ccsr
Sourcepub const fn pll3_sw_clk_sel(&self) -> Pll3SwClkSel
pub const fn pll3_sw_clk_sel(&self) -> Pll3SwClkSel
Selects source to generate pll3_sw_clk. This bit should only be used for testing purposes.
Sourcepub const fn set_pll3_sw_clk_sel(&mut self, val: Pll3SwClkSel)
pub const fn set_pll3_sw_clk_sel(&mut self, val: Pll3SwClkSel)
Selects source to generate pll3_sw_clk. This bit should only be used for testing purposes.