nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Cdcdr

Struct Cdcdr 

#[repr(transparent)]
pub struct Cdcdr(pub u32);
CCM D1 Clock Divider Register

Tuple Fields

0: u32

Implementations

Source

impl Cdcdr

pub const fn spdif0_clk_sel(&self) -> Spdif0ClkSel

Selector for spdif0 clock multiplexer

pub const fn set_spdif0_clk_sel(&mut self, val: Spdif0ClkSel)

Selector for spdif0 clock multiplexer

pub const fn spdif0_clk_podf(&self) -> Spdif0ClkPodf

Divider for spdif0 clock podf. Divider should be updated when output clock is gated.

pub const fn set_spdif0_clk_podf(&mut self, val: Spdif0ClkPodf)

Divider for spdif0 clock podf. Divider should be updated when output clock is gated.

pub const fn spdif0_clk_pred(&self) -> Spdif0ClkPred

Divider for spdif0 clock pred. Divider should be updated when output clock is gated.

pub const fn set_spdif0_clk_pred(&mut self, val: Spdif0ClkPred)

Divider for spdif0 clock pred. Divider should be updated when output clock is gated.