nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Cisr

Struct Cisr 

#[repr(transparent)]
pub struct Cisr(pub u32);
CCM Interrupt Status Register

Tuple Fields

0: u32

Implementations

Source

impl Cisr

pub const fn lrf_pll(&self) -> LrfPll

CCM interrupt request 2 generated due to lock of all enabled and not bypaseed PLLs

pub const fn set_lrf_pll(&mut self, val: LrfPll)

CCM interrupt request 2 generated due to lock of all enabled and not bypaseed PLLs

pub const fn cosc_ready(&self) -> CisrCoscReady

CCM interrupt request 2 generated due to on board oscillator ready, i

pub const fn set_cosc_ready(&mut self, val: CisrCoscReady)

CCM interrupt request 2 generated due to on board oscillator ready, i

pub const fn flexspi_podf_loaded(&self) -> FlexspiPodfLoaded

CCM interrupt request 1 generated due to frequency change of flexspi_podf

pub const fn set_flexspi_podf_loaded(&mut self, val: FlexspiPodfLoaded)

CCM interrupt request 1 generated due to frequency change of flexspi_podf

pub const fn perclk_podf_loaded(&self) -> PerclkPodfLoaded

CCM interrupt request 1 generated due to frequency change of perclk_podf

pub const fn set_perclk_podf_loaded(&mut self, val: PerclkPodfLoaded)

CCM interrupt request 1 generated due to frequency change of perclk_podf

pub const fn ahb_podf_loaded(&self) -> AhbPodfLoaded

CCM interrupt request 1 generated due to frequency change of ahb_podf

pub const fn set_ahb_podf_loaded(&mut self, val: AhbPodfLoaded)

CCM interrupt request 1 generated due to frequency change of ahb_podf

pub const fn periph_clk_sel_loaded(&self) -> PeriphClkSelLoaded

CCM interrupt request 1 generated due to update of periph_clk_sel.

pub const fn set_periph_clk_sel_loaded(&mut self, val: PeriphClkSelLoaded)

CCM interrupt request 1 generated due to update of periph_clk_sel.