nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Cscdr1

Struct Cscdr1 

#[repr(transparent)]
pub struct Cscdr1(pub u32);
CCM Serial Clock Divider Register 1

Tuple Fields

0: u32

Implementations

Source

impl Cscdr1

pub const fn uart_clk_podf(&self) -> UartClkPodf

Divider for uart clock podf.

pub const fn set_uart_clk_podf(&mut self, val: UartClkPodf)

Divider for uart clock podf.

pub const fn uart_clk_sel(&self) -> UartClkSel

Selector for the UART clock multiplexor

pub const fn set_uart_clk_sel(&mut self, val: UartClkSel)

Selector for the UART clock multiplexor

pub const fn trace_podf(&self) -> TracePodf

Divider for trace clock. Divider should be updated when output clock is gated.

pub const fn set_trace_podf(&mut self, val: TracePodf)

Divider for trace clock. Divider should be updated when output clock is gated.