Struct Ccgr3
Source #[repr(transparent)]
pub struct Ccgr3(pub u32);
CCM Clock Gating Register 3
aoi1 clock (aoi1_clk_enable)
aoi1 clock (aoi1_clk_enable)
ewm clocks (ewm_clk_enable)
ewm clocks (ewm_clk_enable)
wdog1 clock (wdog1_clk_enable)
wdog1 clock (wdog1_clk_enable)
flexram clock (flexram_clk_enable)
flexram clock (flexram_clk_enable)
The OCRAM clock cannot be turned off when the CM cache is running on this device.
The OCRAM clock cannot be turned off when the CM cache is running on this device.
iomuxc_snvs_gpr clock (iomuxc_snvs_gpr_clk_enable)
iomuxc_snvs_gpr clock (iomuxc_snvs_gpr_clk_enable)
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.