#[repr(transparent)]pub struct Ccosr(pub u32);Expand description
CCM Clock Output Source Register
Tuple Fields
0: u32Implementations
Sourceimpl Ccosr
impl Ccosr
Sourcepub const fn set_clko1_sel(&mut self, val: Clko1Sel)
pub const fn set_clko1_sel(&mut self, val: Clko1Sel)
Selection of the clock to be generated on CCM_CLKO1
Sourcepub const fn set_clko1_div(&mut self, val: Clko1Div)
pub const fn set_clko1_div(&mut self, val: Clko1Div)
Setting the divider of CCM_CLKO1
Sourcepub const fn set_clko1_en(&mut self, val: Clko1En)
pub const fn set_clko1_en(&mut self, val: Clko1En)
Enable of CCM_CLKO1 clock
Sourcepub const fn clk_out_sel(&self) -> ClkOutSel
pub const fn clk_out_sel(&self) -> ClkOutSel
CCM_CLKO1 output to reflect CCM_CLKO1 or CCM_CLKO2 clocks
Sourcepub const fn set_clk_out_sel(&mut self, val: ClkOutSel)
pub const fn set_clk_out_sel(&mut self, val: ClkOutSel)
CCM_CLKO1 output to reflect CCM_CLKO1 or CCM_CLKO2 clocks
Sourcepub const fn set_clko2_sel(&mut self, val: Clko2Sel)
pub const fn set_clko2_sel(&mut self, val: Clko2Sel)
Selection of the clock to be generated on CCM_CLKO2
Sourcepub const fn set_clko2_div(&mut self, val: Clko2Div)
pub const fn set_clko2_div(&mut self, val: Clko2Div)
Setting the divider of CCM_CLKO2
Sourcepub const fn set_clko2_en(&mut self, val: Clko2En)
pub const fn set_clko2_en(&mut self, val: Clko2En)
Enable of CCM_CLKO2 clock