#[repr(transparent)]pub struct Cscdr1(pub u32);Expand description
CCM Serial Clock Divider Register 1
Tuple Fields
0: u32Implementations
Sourceimpl Cscdr1
impl Cscdr1
Sourcepub const fn uart_clk_podf(&self) -> UartClkPodf
pub const fn uart_clk_podf(&self) -> UartClkPodf
Divider for uart clock podf.
Sourcepub const fn set_uart_clk_podf(&mut self, val: UartClkPodf)
pub const fn set_uart_clk_podf(&mut self, val: UartClkPodf)
Divider for uart clock podf.
Sourcepub const fn uart_clk_sel(&self) -> UartClkSel
pub const fn uart_clk_sel(&self) -> UartClkSel
Selector for the UART clock multiplexor
Sourcepub const fn set_uart_clk_sel(&mut self, val: UartClkSel)
pub const fn set_uart_clk_sel(&mut self, val: UartClkSel)
Selector for the UART clock multiplexor
Sourcepub const fn trace_podf(&self) -> TracePodf
pub const fn trace_podf(&self) -> TracePodf
Divider for trace clock. Divider should be updated when output clock is gated.
Sourcepub const fn set_trace_podf(&mut self, val: TracePodf)
pub const fn set_trace_podf(&mut self, val: TracePodf)
Divider for trace clock. Divider should be updated when output clock is gated.